@@ -29,9 +29,9 @@
 #include <ctype.h>
 #include <dirent.h>
 #include <math.h>
+#include <sys/types.h>
 #include <regex.h>
 #include <string.h>
-#include <sys/types.h>
 
 #include <capplet-widget.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -40,6 +40,7 @@
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-mime-info.h>
+#include <libgnomevfs/gnome-vfs-init.h>
 
 #include "nautilus-mime-type-capplet-dialogs.h"
 #include "nautilus-mime-type-icon-entry.h"
@@ -62,7 +63,6 @@ static void	 add_mime_clicked 	  		(GtkWidget 	*widget,
 static void	 edit_default_clicked 			(GtkWidget 	*widget, 	
 						 	 gpointer   	data);
 static GtkWidget *create_mime_list_and_scroller 	(void);
-static char 	 *pixmap_file 				(const char 	*partial_path);
 static void 	 ok_callback 		  		(void);
 static void	 gtk_widget_make_bold 			(GtkWidget 	*widget);
 static GdkFont 	 *gdk_font_get_bold 			(const GdkFont  *plain_font);
@@ -75,15 +75,15 @@ static GdkPixbuf *capplet_gdk_pixbuf_scale_to_fit 	(GdkPixbuf 	*pixbuf,
 							 int 		max_height);
 
 
-GtkWidget *capplet = NULL;
-GtkWidget *delete_button = NULL;
-GtkWidget *remove_button = NULL;
-GtkWidget *add_button = NULL;
+GtkWidget *capplet;
+GtkWidget *delete_button;
+GtkWidget *remove_button;
+GtkWidget *add_button;
 GtkWidget *icon_entry, *extension_list, *mime_list;
 GtkWidget *default_menu;
 GtkWidget *application_button, *viewer_button;
-GtkLabel  *icon_entry_label;
-GtkWidget *description_entry, *mime_label;
+GtkLabel  *mime_label;
+GtkWidget *description_entry;
 
 /*
  *  main
@@ -106,6 +106,8 @@ main (int argc, char **argv)
                 exit (0);
 	}
 
+	gnome_vfs_init ();
+
 	if (init_results == 0) {
 		init_mime_capplet ();
 	        capplet_gtk_main ();
@@ -260,8 +262,6 @@ mime_list_selected_row_callback (GtkWidget *widget, gint row, gint column, GdkEv
 
 	/* Update info on selection */
         nautilus_mime_type_capplet_update_info (mime_type);
-        
-	/* FIXME: Get user mime info and determine if we can enable the delete button */
 }
 
 static void
@@ -295,25 +295,6 @@ viewer_button_toggled (GtkToggleButton *button, gpointer user_data)
 	}
 }
 
-static void 
-icon_changed (GtkWidget *entry, gpointer user_data)
-{
-	gchar *path, *filename;
-	const char *mime_type;
-	
-	path = nautilus_mime_type_icon_entry_get_filename (NAUTILUS_MIME_ICON_ENTRY (icon_entry));
-	if (path != NULL) {
-		g_message ("%s", path);
-		filename = strrchr (path, '/');
-		if (filename != NULL) {
-			filename++;
-			mime_type = nautilus_mime_type_capplet_get_selected_item_mime_type ();
-			gnome_vfs_mime_set_icon (mime_type, filename);
-		}
-		g_free (path);
-	}
-}
-
 static void 
 change_icon_clicked (GtkWidget *entry, gpointer user_data)
 {
@@ -331,7 +312,6 @@ init_mime_capplet (void)
         GtkWidget *frame;
         GtkWidget *alignment;
         GtkWidget *table, *extensions_table;
-	//GList     *children;
 	int index, list_width, column_width;
 	
 	capplet = capplet_widget_new ();
@@ -364,14 +344,11 @@ init_mime_capplet (void)
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 
 	icon_entry = nautilus_mime_type_icon_entry_new ("mime_icon_entry", NULL);
-	gtk_signal_connect (GTK_OBJECT (nautilus_mime_type_icon_entry_gtk_entry (NAUTILUS_MIME_ICON_ENTRY (icon_entry))),
-			    "changed", icon_changed, NULL);
 	gtk_box_pack_start (GTK_BOX (vbox), icon_entry, FALSE, FALSE, 0);
 	
 	button = gtk_button_new_with_label (_("Change Icon"));
 	gtk_signal_connect (GTK_OBJECT (button), "clicked", change_icon_clicked, icon_entry);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);	
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 
@@ -381,18 +358,16 @@ init_mime_capplet (void)
 	gtk_container_add (GTK_CONTAINER (alignment), description_entry);
 	gtk_widget_set_usize (description_entry, 200, 0);
 	gtk_widget_make_bold (GTK_WIDGET (description_entry));
-	
-	mime_label = gtk_label_new (_("Mime Type"));	
+	mime_label = GTK_LABEL (gtk_label_new (_("Mime Type")));	
 	gtk_label_set_justify (GTK_LABEL (mime_label), GTK_JUSTIFY_RIGHT);
 	alignment = gtk_alignment_new (0, 0, 0, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (alignment), mime_label);
+	gtk_container_add (GTK_CONTAINER (alignment), GTK_WIDGET(mime_label));
 
 	/* Set up bottom left area.  This contains two buttons to add
 	   and delete mime types */
 	vbox = gtk_vbox_new (FALSE, 7);
 	gtk_table_attach_defaults ( GTK_TABLE (table), vbox, 0, 1, 1, 2);
-	
 	/* Put in a spacer to make buttons layout as we want them */
 	{
 		GtkWidget *spacer;
@@ -411,14 +386,14 @@ init_mime_capplet (void)
 	alignment = gtk_alignment_new (0, 0, 0, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
 
-	button = gtk_button_new_with_label (_("Delete this Mime type..."));
-	gtk_container_add (GTK_CONTAINER (alignment), button);
+	delete_button = gtk_button_new_with_label (_("Delete this Mime type..."));
+	gtk_container_add (GTK_CONTAINER (alignment), delete_button);
 	gtk_signal_connect (GTK_OBJECT (delete_button), "clicked", delete_mime_clicked, NULL);
 
 	/* Set up top right area. */
 	frame = gtk_frame_new ("Default Action:");
 	gtk_table_attach_defaults ( GTK_TABLE (table), frame, 1, 2, 0, 1);
-	
+
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
@@ -488,13 +463,16 @@ init_mime_capplet (void)
 	gtk_signal_connect (GTK_OBJECT (extension_list), "unselect-row",
 			    GTK_SIGNAL_FUNC (extension_list_deselected), NULL);
 
-
 	/* Set up enabled/disabled states of capplet buttons */	
 	gtk_widget_set_sensitive (add_button, TRUE);
 	gtk_widget_set_sensitive (remove_button, FALSE);
 	
+	/* FIXME bugzilla.eazel.com 2765: this call generates a 
+	   Gtk-WARNING **: gtk_signal_disconnect_by_data(): could not find handler containing data (0x80FA6F8)
+	*/
+
 	/* Yes, show all widgets */
-        gtk_widget_show_all (capplet);
+	gtk_widget_show_all (capplet);
 
 	/* Make columns all fit within capplet list view bounds */
 	list_width = GTK_WIDGET (mime_list)->allocation.width;
@@ -533,8 +511,7 @@ nautilus_mime_type_capplet_update_info (const char *mime_type) {
 	/* Update text items */
 	gtk_label_set_text (GTK_LABEL (mime_label), mime_type);
 
-	/* Add description to first column */
-	description = gnome_vfs_mime_description (mime_type);	
+	description = gnome_vfs_mime_get_description (mime_type);	
 	if (description != NULL && strlen (description) > 0) {
 		gtk_entry_set_text (GTK_ENTRY (description_entry), description);
 	} else {
@@ -555,12 +532,18 @@ nautilus_mime_type_capplet_update_info (const char *mime_type) {
 
 	/* Set icon for mime type */
 	icon_name = gnome_vfs_mime_get_icon (mime_type);
-	path = pixmap_file (icon_name);
-	nautilus_mime_type_icon_entry_set_icon (NAUTILUS_MIME_ICON_ENTRY (icon_entry), path);
-	if (path != NULL) {
-		g_free (path);
+	if (icon_name != NULL) {
+		path = gnome_pixmap_file (icon_name);
+		if (path != NULL) {
+			nautilus_mime_type_icon_entry_set_icon (NAUTILUS_MIME_ICON_ENTRY (icon_entry), path);
+			g_free (path);
+		} else {
+			/* No icon */
+			nautilus_mime_type_icon_entry_set_icon (NAUTILUS_MIME_ICON_ENTRY (icon_entry), NULL);
+		}
 	} else {
-		gtk_label_set_text (icon_entry_label, NULL);		
+		/* No icon */
+		nautilus_mime_type_icon_entry_set_icon (NAUTILUS_MIME_ICON_ENTRY (icon_entry), NULL);
 	}
 
 	/* Indicate default action */	
@@ -716,6 +699,7 @@ populate_application_menu (GtkWidget *application_menu, const char *mime_type)
 				/* Set it as active */
 				gtk_menu_set_active (GTK_MENU (new_menu), index);
 			}
+			gnome_vfs_mime_application_free (default_app);
 		}
 	}
 	
@@ -743,37 +727,38 @@ component_menu_activated (GtkWidget *menu_item, gpointer data)
 static void
 populate_viewer_menu (GtkWidget *component_menu, const char *mime_type)
 {
-	GtkWidget *new_menu;
-	GtkWidget *menu_item;
+	GtkWidget *new_menu, *menu_item;
 	GList *component_list, *copy_list;
-	GList *list_element;
-	gboolean has_none, found_match;
-	char *component_name;
 	OAF_ServerInfo *default_component;
 	OAF_ServerInfo *info;
+	gboolean has_none, found_match;
+	char *mime_copy, *component_name;
 	const char *iid;
 	GList *children;
 	int index;
-	
+
 	has_none = TRUE;
 	found_match = FALSE;
 
+	mime_copy = g_strdup (mime_type);
+	
 	new_menu = gtk_menu_new ();
 	
 	/* Get the default component */
 	default_component = gnome_vfs_mime_get_default_component (mime_type);
 
-	/* Fill list with default components */
+	/* Get the component short list */
 	component_list = gnome_vfs_mime_get_short_list_components (mime_type);
 	if (component_list != NULL) {
-		for (list_element = component_list; list_element != NULL; list_element = list_element->next) {
+		for (copy_list = component_list; copy_list != NULL; copy_list = copy_list->next) {
 			has_none = FALSE;
 
-			component_name = name_from_oaf_server_info (list_element->data);
+			component_name = name_from_oaf_server_info (copy_list->data);
 			menu_item = gtk_menu_item_new_with_label (component_name);
+			g_free (component_name);
 
 			/* Store copy of component name and mime type in item; free when item destroyed. */
-			info = list_element->data;
+			info = copy_list->data;
 			gtk_object_set_data_full (GTK_OBJECT (menu_item),
 						  "iid",
 						  g_strdup (info->iid),
@@ -790,11 +775,11 @@ populate_viewer_menu (GtkWidget *component_menu, const char *mime_type)
 			gtk_signal_connect (GTK_OBJECT (menu_item), "activate", 
 					    component_menu_activated, NULL);
 		}
-
+	
 		gnome_vfs_mime_component_list_free (component_list);
 	}
-	
-	/* Add a "None" item */
+
+	/* Find all components or add a "None" item */
 	if (has_none && default_component == NULL) {		
 		menu_item = gtk_menu_item_new_with_label (_("None"));
 		gtk_menu_append (GTK_MENU (new_menu), menu_item);
@@ -817,17 +802,16 @@ populate_viewer_menu (GtkWidget *component_menu, const char *mime_type)
 
 			/* See if we have a match */
 			if (found_match) {
-				/* Have menu appear with default application selected */
+				/* Have menu appear with default component selected */
 				gtk_menu_set_active (GTK_MENU (new_menu), index);
 			} else {
 				/* No match found.  We need to insert a menu item
-				 * and add the application to the default list */
-
-				component_name = name_from_oaf_server_info (copy_list->data);
+				 * and add the component to the default list */
+				component_name = name_from_oaf_server_info (default_component);
 				menu_item = gtk_menu_item_new_with_label (component_name);
+				g_free (component_name);
 
-
-				/* Store copy of application name and mime type in item; free when item destroyed. */
+				/* Store copy of component name and mime type in item; free when item destroyed. */
 				gtk_object_set_data_full (GTK_OBJECT (menu_item),
 							  "iid",
 							  g_strdup (default_component->iid),
@@ -861,6 +845,7 @@ populate_viewer_menu (GtkWidget *component_menu, const char *mime_type)
 				/* Set it as active */
 				gtk_menu_set_active (GTK_MENU (new_menu), index);
 			}
+			CORBA_free (default_component);
 		}
 	}
 	
@@ -887,7 +872,7 @@ delete_mime_clicked (GtkWidget *widget, gpointer data)
         mime_type = (const char *) gtk_clist_get_row_data (GTK_CLIST (mime_list), row);
 
         gtk_clist_remove (GTK_CLIST (mime_list), row);
-	/* FIXME: Get user mime info */
+	/* FIXME bugzilla.eazel.com 2767: Get user mime info */
         //g_hash_table_remove (user_mime_types, mi->mime_type);
 	//remove_mime_info (mi->mime_type);
 }
@@ -895,7 +880,121 @@ delete_mime_clicked (GtkWidget *widget, gpointer data)
 static void
 add_mime_clicked (GtkWidget *widget, gpointer data)
 {
-	nautilus_mime_type_capplet_show_new_mime_window ();
+	static gchar *text[3];        
+	const char *description, *action_icon_name, *description_icon_name;
+	char *extensions, *mime_string, *action_icon_path, *description_icon_path;
+        gint row;
+	GdkPixbuf *pixbuf;
+	GdkPixmap *pixmap;
+	GdkBitmap *bitmap;
+	GnomeVFSMimeAction *action;
+	GnomeVFSMimeApplication *default_app;
+	OAF_ServerInfo *default_component;
+	
+	mime_string = nautilus_mime_type_capplet_show_new_mime_window ();
+	if (mime_string != NULL) {
+		/* Add new type to mime list */
+		pixbuf = NULL;
+			
+		/* Add description to first column */
+		description = gnome_vfs_mime_get_description (mime_string);	
+		if (description != NULL && strlen (description) > 0) {
+			text[0] = g_strdup (description);
+		} else {
+			text[0] = g_strdup ("");
+		}
+
+		/* Add mime type to second column */
+		text[1] = mime_string;
+
+		/* Add extension to third columns */
+		extensions = gnome_vfs_mime_get_extensions_pretty_string (mime_string);
+		if (extensions != NULL) {
+			text[2] = extensions;
+		} else {
+			text[2] = "";
+		}
+
+		/* Add default action to fourth column */
+		text[3] = g_strdup(_("None"));
+
+		/* Insert item into list */
+		row = gtk_clist_insert (GTK_CLIST (mime_list), 1, text);
+	        gtk_clist_set_row_data (GTK_CLIST (mime_list), row, g_strdup(mime_string));
+
+		/* Set description column icon */
+		description_icon_name = gnome_vfs_mime_get_icon (mime_string);			
+		if (description_icon_name != NULL) {
+			/* Get custom icon */
+			description_icon_path = gnome_pixmap_file (description_icon_name);
+			if (description_icon_path != NULL) {
+				pixbuf = gdk_pixbuf_new_from_file (description_icon_path);
+				g_free (description_icon_path);
+			}
+		} else {
+			/* Use default icon */
+			pixbuf = gdk_pixbuf_new_from_file ("/gnome/share/pixmaps/nautilus/i-regular-24.png");
+		}
+
+		if (pixbuf != NULL) {
+			pixbuf = capplet_gdk_pixbuf_scale_to_fit (pixbuf, 18, 18);
+			gdk_pixbuf_render_pixmap_and_mask (pixbuf, &pixmap, &bitmap, 100);
+			gtk_clist_set_pixtext (GTK_CLIST (mime_list), row, 0, text[0], 5, pixmap, bitmap);
+			gdk_pixbuf_unref (pixbuf);
+		}
+
+		/* Set up action column */
+		pixbuf = NULL;
+		action = gnome_vfs_mime_get_default_action (mime_string);
+		if (action != NULL) {
+			switch (action->action_type) {
+				case GNOME_VFS_MIME_ACTION_TYPE_APPLICATION:
+					/* Get the default application */
+					default_app = gnome_vfs_mime_get_default_application (mime_string);
+					g_free (text[3]);
+					text[3] = g_strdup (default_app->name);
+					action_icon_name = gnome_vfs_mime_get_icon (mime_string);			
+					if (action_icon_name != NULL) {
+						/* Get custom icon */
+						action_icon_path = gnome_pixmap_file (action_icon_name);
+						if (action_icon_path != NULL) {
+							pixbuf = gdk_pixbuf_new_from_file (action_icon_path);
+							g_free (action_icon_path);
+						}
+					} else {
+						/* Use default icon */
+						pixbuf = gdk_pixbuf_new_from_file ("/gnome/share/pixmaps/nautilus/i-executable.png");
+					}
+					gnome_vfs_mime_application_free (default_app);
+					break;
+
+				case GNOME_VFS_MIME_ACTION_TYPE_COMPONENT:
+					/* Get the default component */
+					default_component = gnome_vfs_mime_get_default_component (mime_string);
+					g_free (text[3]);
+					text[3] = name_from_oaf_server_info (default_component);
+					pixbuf = gdk_pixbuf_new_from_file ("/gnome/share/pixmaps/nautilus/gnome-library.png");
+					CORBA_free (default_component);
+					break;
+					
+				default:
+					gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (application_button), TRUE);
+					break;
+			}
+		}
+				
+		/* Set column icon */
+		if (pixbuf != NULL) {
+			pixbuf = capplet_gdk_pixbuf_scale_to_fit (pixbuf, 18, 18);
+			gdk_pixbuf_render_pixmap_and_mask (pixbuf, &pixmap, &bitmap, 100);
+			gtk_clist_set_pixtext (GTK_CLIST (mime_list), row, 3, text[3], 5, pixmap, bitmap);
+			gdk_pixbuf_unref (pixbuf);
+		}
+		
+		g_free (text[0]);
+		g_free (text[3]);
+		g_free (extensions);
+	}
 }
 
 static void
@@ -963,9 +1062,11 @@ nautilus_mime_type_capplet_update_viewer_info (const char *mime_type)
 static void
 populate_mime_list (GList *type_list, GtkCList *clist)
 {
-	static gchar *text[3];        
-	const char *description, *action_icon_name, *description_icon_name;
-	char *extensions, *mime_string, *action_icon_path, *description_icon_path;
+	static gchar *text[4];        
+	const char *description, *description_icon_name;
+	const char *action_icon_name;
+	char *extensions, *mime_string, *description_icon_path;
+	char *action_icon_path;
         gint row;
 	GList *element;
 	GdkPixbuf *pixbuf;
@@ -975,16 +1076,17 @@ populate_mime_list (GList *type_list, GtkCList *clist)
 	GnomeVFSMimeApplication *default_app;
 	OAF_ServerInfo *default_component;
 
-	//gtk_clist_set_row_height (clist, 20);
-	
+	//gtk_clist_set_row_height (clist, 20);		
 	for (element = type_list; element != NULL; element= element->next) {
 		mime_string = (char *)element->data;
 		
 		/* Make sure we do not include comments */
 		if (mime_string[0] != '#') {
 
+			pixbuf = NULL;
+			
 			/* Add description to first column */
-			description = gnome_vfs_mime_description (mime_string);	
+			description = gnome_vfs_mime_get_description (mime_string);	
 			if (description != NULL && strlen (description) > 0) {
 				text[0] = g_strdup (description);
 			} else {
@@ -1003,7 +1105,7 @@ populate_mime_list (GList *type_list, GtkCList *clist)
 			}
 
 			/* Add default action to fourth column */
-			text[3] = _("None");
+			text[3] = g_strdup(_("None"));
 
 			/* Insert item into list */
 			row = gtk_clist_insert (GTK_CLIST (clist), 1, text);
@@ -1013,8 +1115,11 @@ populate_mime_list (GList *type_list, GtkCList *clist)
 			description_icon_name = gnome_vfs_mime_get_icon (mime_string);			
 			if (description_icon_name != NULL) {
 				/* Get custom icon */
-				description_icon_path = pixmap_file (description_icon_name);
-				pixbuf = gdk_pixbuf_new_from_file (description_icon_path);				
+				description_icon_path = gnome_pixmap_file (description_icon_name);
+				if (description_icon_path != NULL) {
+					pixbuf = gdk_pixbuf_new_from_file (description_icon_path);
+					g_free (description_icon_path);
+				}
 			} else {
 				/* Use default icon */
 				pixbuf = gdk_pixbuf_new_from_file ("/gnome/share/pixmaps/nautilus/i-regular-24.png");
@@ -1030,29 +1135,36 @@ populate_mime_list (GList *type_list, GtkCList *clist)
 			/* Set up action column */
 			pixbuf = NULL;
 			action = gnome_vfs_mime_get_default_action (mime_string);
-			if (action != NULL) {
+			if (action != NULL) {				
 				switch (action->action_type) {
 					case GNOME_VFS_MIME_ACTION_TYPE_APPLICATION:
 						/* Get the default application */
-						default_app = gnome_vfs_mime_get_default_application (mime_string);
-						text[3] = default_app->name;
-
+						default_app = gnome_vfs_mime_get_default_application (mime_string);						
+						g_free (text[3]);
+						text[3] = g_strdup (default_app->name);
+												
 						action_icon_name = gnome_vfs_mime_get_icon (mime_string);			
 						if (action_icon_name != NULL) {
 							/* Get custom icon */
-							action_icon_path = pixmap_file (action_icon_name);
-							pixbuf = gdk_pixbuf_new_from_file (action_icon_path);				
+							action_icon_path = gnome_pixmap_file (action_icon_name);
+							if (action_icon_path != NULL) {
+								pixbuf = gdk_pixbuf_new_from_file (action_icon_path);
+								g_free (action_icon_path);
+							}
 						} else {
 							/* Use default icon */
 							pixbuf = gdk_pixbuf_new_from_file ("/gnome/share/pixmaps/nautilus/i-executable.png");
 						}
+						gnome_vfs_mime_application_free (default_app);
 						break;
 
 					case GNOME_VFS_MIME_ACTION_TYPE_COMPONENT:
 						/* Get the default component */
 						default_component = gnome_vfs_mime_get_default_component (mime_string);
+						g_free (text[3]);
 						text[3] = name_from_oaf_server_info (default_component);
 						pixbuf = gdk_pixbuf_new_from_file ("/gnome/share/pixmaps/nautilus/gnome-library.png");
+						CORBA_free (default_component);
 						break;
 						
 					default:
@@ -1068,9 +1180,10 @@ populate_mime_list (GList *type_list, GtkCList *clist)
 				gtk_clist_set_pixtext (clist, row, 3, text[3], 5, pixmap, bitmap);
 				gdk_pixbuf_unref (pixbuf);
 			}
-			
+												
 			g_free (text[0]);
-			g_free (extensions);
+			g_free (text[3]);
+			g_free (extensions);			
 		}
 	}
 }
@@ -1147,7 +1260,7 @@ nautilus_mime_type_capplet_get_selected_item_mime_type (void)
 	}
 
 	/* This is a single selection list, so we just use the first item in 
-	 * the list to retireve the data */
+	 * the list to retrieve the data */
 	row = GPOINTER_TO_INT (clist->selection->data);
 
 	mime_type = (const char *) gtk_clist_get_row_data (clist, row);
@@ -1155,57 +1268,6 @@ nautilus_mime_type_capplet_get_selected_item_mime_type (void)
 	return mime_type;
 }
 
-
-/**
- * make_path:
- * 
- * Make a path name from a base path and name. The base path
- * can end with or without a separator character.
- *
- * Return value: the combined path name.
- **/
-static char * 
-make_path (const char *path, const char* name)
-{
-    	gboolean insert_separator;
-    	int path_length;
-	char *result;
-
-	path_length = strlen (path);
-    	insert_separator = path_length > 0 && 
-    			   name[0] != '\0' && 
-    			   path[path_length - 1] != G_DIR_SEPARATOR;
-
-    	if (insert_separator) {
-    		result = g_strconcat (path, G_DIR_SEPARATOR_S, name, NULL);
-    	} else {
-    		result = g_strconcat (path, name, NULL);
-    	}
-
-	return result;
-}
-
-static char *
-pixmap_file (const char *partial_path)
-{
-	char *path;
-
-	if (partial_path == NULL) {
-		return NULL;
-	}
-
-	/* FIXME: Where to get DATADIR? */
-	/*path = make_path (DATADIR "/pixmaps/nautilus", partial_path);*/
-	path = make_path ("/gnome/share/pixmaps/nautilus", partial_path);
-	if (g_file_exists (path)) {
-		return path;
-	} else {
-		g_free (path);
-		return NULL;
-	}
-}
-
-
 /**
  * gtk_label_make_bold.
  *
