@@ -36,6 +36,13 @@
 #include "gnome-vfs-mime.h"
 #include "bzip2-method.h"
 
+#ifdef HAVE_OLDER_BZIP2
+#define BZ2_bzDecompressInit  bzDecompressInit
+#define BZ2_bzCompressInit    bzCompressInit
+#define BZ2_bzDecompress      bzDecompress
+#define BZ2_bzCompress        bzCompress
+#endif
+
 #define BZ_BUFSIZE   5000
 
 struct _Bzip2MethodHandle {
@@ -97,19 +104,21 @@ static GnomeVFSMethod method = {
 	do_create,
 	do_close,
 	do_read,
-	do_write,		/* write           */
+	do_write,
 	NULL,		/* seek            */
 	NULL,		/* tell            */
 	NULL,		/* truncate_handle */
 	NULL,		/* open_directory  */
 	NULL,		/* close_directory */
 	NULL,		/* read_directory  */
-	do_get_file_info,	/* get_file_info   */
+	do_get_file_info,
 	NULL,		/* get_file_info_from_handle */
 	do_is_local,
 	NULL,		/* make_directory  */
 	NULL,		/* remove_directory */
-	NULL,			/* rename */
+	NULL,		/* move */
+	NULL,		/* unlink */
+	NULL,		/* set_file_info */
 	NULL, 		/* truncate */
 	NULL, 		/* find_directory */
 	NULL            /* create_symbolic_link */
@@ -166,7 +175,7 @@ bzip2_method_handle_init_for_decompress (Bzip2MethodHandle *handle)
 	handle->bzstream.avail_in = 0;
 
 	/* FIXME bugzilla.eazel.com 1177: Make small, and possibly verbosity, configurable! */
-	if (bzDecompressInit (&handle->bzstream, 0, 0) != BZ_OK) {
+	if (BZ2_bzDecompressInit (&handle->bzstream, 0, 0) != BZ_OK) {
 		g_free (handle->buffer);
 		return FALSE;
 	}
@@ -194,7 +203,7 @@ bzip2_method_handle_init_for_compress (Bzip2MethodHandle *handle)
 	handle->bzstream.avail_out = BZ_BUFSIZE;
 
 	/* FIXME bugzilla.eazel.com 1174: We want this to be user configurable.  */
-	if (bzCompressInit (&handle->bzstream, 3, 0, 30) != BZ_OK) {
+	if (BZ2_bzCompressInit (&handle->bzstream, 3, 0, 30) != BZ_OK) {
 		g_free (handle->buffer);
 		return FALSE;
 	}
@@ -264,7 +273,7 @@ flush_write (Bzip2MethodHandle *bzip2_handle)
 		if (done)
 			break;
 
-		bz_result = bzCompress (bzstream, BZ_FINISH);
+		bz_result = BZ2_bzCompress (bzstream, BZ_FINISH);
 
 		done = (bzstream->avail_out != 0 || bz_result == BZ_STREAM_END);
 	}
@@ -365,7 +374,6 @@ do_close (GnomeVFSMethod *method,
 	if (result == GNOME_VFS_OK)
 		result = gnome_vfs_close (bzip2_handle->parent_handle);
 
-	/* FIXME bugzilla.eazel.com 1169: How do we deal with close errors? */
 	bzip2_method_handle_destroy (bzip2_handle);
 
 	return result;
@@ -439,7 +447,7 @@ do_read (GnomeVFSMethod *method,
 		result = fill_buffer (bzip2_handle, num_bytes);
 		RETURN_IF_FAIL (result);
 
-		bz_result = bzDecompress (&bzip2_handle->bzstream);
+		bz_result = BZ2_bzDecompress (&bzip2_handle->bzstream);
 
 		if (bzip2_handle->last_bz_result != BZ_OK
 		    && bzstream->avail_out == num_bytes) {
@@ -496,7 +504,7 @@ do_write (GnomeVFSMethod *method,
 			bzstream->avail_out += written;
 		}
 
-		bz_result = bzCompress (bzstream, BZ_RUN);
+		bz_result = BZ2_bzCompress (bzstream, BZ_RUN);
 		result = result_from_bz_result (bz_result);
 	}
 
@@ -530,7 +538,7 @@ do_get_file_info  (GnomeVFSMethod *method,
 		gint namelen = strlen(file_info->name);
 		
 		/* work out the name */
-		/* FIXME handle uppercase */
+		/* FIXME bugzilla.eazel.com 2790: handle uppercase */
 		if(namelen > 4 &&
 				file_info->name[namelen-1] == '2' &&
 				file_info->name[namelen-2] == 'z' &&
@@ -542,7 +550,7 @@ do_get_file_info  (GnomeVFSMethod *method,
 		//file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;
 
 		/* guess the mime type of the file inside */
-		/* FIXME guess mime based on contents */
+		/* FIXME bugzilla.eazel.com 2791: guess mime based on contents */
 		g_free(file_info->mime_type);
 		file_info->mime_type = g_strdup(gnome_vfs_mime_type_from_name(file_info->name));
 	}
