@@ -38,8 +38,6 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <libgnome/libgnome.h>
-
 #include "gnome-vfs.h"
 #include "gnome-vfs-private.h"
 #include "gnome-vfs-mime.h"
@@ -739,7 +737,7 @@ do_get_file_info (GnomeVFSMethod *method,
 		/* now we get evil and tell the app that this is in fact a dir */
 		file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
 		g_free(file_info->mime_type);
-		file_info->mime_type = g_strdup("x-special/directory");
+		file_info->mime_type = g_strdup("x-directory/normal");
 		g_free(filename);
 		return result;
 	}
@@ -791,6 +789,7 @@ do_find_directory (GnomeVFSMethod *method,
 		   GnomeVFSFindDirectoryKind kind,
 		   GnomeVFSURI **result_uri,
 		   gboolean create_if_needed,
+		   gboolean find_if_needed,
 		   guint permissions,
 		   GnomeVFSContext *context)
 {
@@ -859,7 +858,7 @@ static GnomeVFSMethod method = {
 	NULL,
 	do_truncate,
 	do_find_directory,
-	NULL     /* FIXME: do_create_symbolic_link */
+	NULL     /* FIXME bugzilla.eazel.com 2804: do_create_symbolic_link */
 };
 
 GnomeVFSMethod *
