@@ -117,20 +117,22 @@ static GnomeVFSMethod method = {
 	do_create,
 	do_close,
 	do_read,
-	do_write,		/* write */
+	do_write,
 	NULL,			/* seek */
 	NULL,			/* tell */
 	NULL,			/* truncate_handle FIXME bugzilla.eazel.com 1175 */
 	NULL,			/* open_directory */
 	NULL,			/* close_directory */
 	NULL,			/* read_directory */
-	do_get_file_info,	/* get_file_info */
+	do_get_file_info,
 	NULL,			/* get_file_info_from_handle */
 	do_is_local,
 	NULL,			/* make_directory */
 	NULL,			/* remove_directory */
-	NULL,			/* rename */
+	NULL,			/* move */
 	NULL,                   /* unlink */
+	NULL,			/* check_same_fs */
+	NULL,			/* set_file_info */
 	NULL, 			/* truncate */
 	NULL,			/* find_directory */
 	NULL                    /* create_symbolic_link */
@@ -559,7 +561,6 @@ do_close (GnomeVFSMethod *method,
 	if (result == GNOME_VFS_OK)
 		result = gnome_vfs_close (gzip_handle->parent_handle);
 
-	/* FIXME bugzilla.eazel.com 1169: How do we deal with close errors?  */
 	gzip_method_handle_destroy (gzip_handle);
 
 	return result;
@@ -728,7 +729,7 @@ do_get_file_info  (GnomeVFSMethod *method,
 		gint namelen = strlen(file_info->name);
 		
 		/* work out the name */
-		/* FIXME handle uppercase */
+		/* FIXME bugzilla.eazel.com 2790: handle uppercase */
 		if(namelen > 3 &&
 				file_info->name[namelen-1] == 'z' &&
 				file_info->name[namelen-2] == 'g' &&
@@ -739,7 +740,7 @@ do_get_file_info  (GnomeVFSMethod *method,
 		//file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;
 
 		/* guess the mime type of the file inside */
-		/* FIXME guess mime based on contents */
+		/* FIXME bugzilla.eazel.com 2791: guess mime based on contents */
 		g_free(file_info->mime_type);
 		file_info->mime_type = g_strdup(gnome_vfs_mime_type_from_name(file_info->name));
 	}
